@@ -1,11 +1,10 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-// $Id:$
 
 #include "config.h" // autoconf defines, needed by the dune headers
 
 // dune headers
-#include <dune/grid/sgrid.hh>
+#include <dune/grid/yaspgrid.hh>
 #include <dune/grid/io/file/vtk/vtksequencewriter.hh>
 
 #include <vector>
@@ -79,7 +78,8 @@ void doWrite( const GridView &gridView, Dune::VTK::DataMode dm )
 
   vtk.addVertexData(vertexdata,"vertexData");
   vtk.addCellData(celldata,"cellData");
-  VTKVectorFunction< GridView > *vectordata = new VTKVectorFunction< GridView >;
+  Dune::shared_ptr<VTKVectorFunction<GridView> > vectordata
+    (new VTKVectorFunction< GridView >);
   vtk.addVertexData(vectordata);
   double time = 0;
   while (time<1) {
@@ -90,31 +90,46 @@ void doWrite( const GridView &gridView, Dune::VTK::DataMode dm )
 }
 
 template<int dim>
-void vtkCheck(int* n, double* h)
+void vtkCheck(const Dune::array<int,dim>& n,
+              const Dune::FieldVector<double,dim>& h)
 {
-  const Dune :: PartitionIteratorType VTK_Partition = Dune :: InteriorBorder_Partition;
   std::cout << std::endl << "vtkSequenceCheck dim=" << dim << std::endl << std::endl;
-  Dune::SGrid<dim,dim> g(n, h);
+  Dune::YaspGrid<dim> g(h, n);
   g.globalRefine(1);
 
-  doWrite( g.template leafGridView< VTK_Partition >(), Dune::VTK::conforming );
-  doWrite( g.template leafGridView< VTK_Partition >(), Dune::VTK::nonconforming );
-  doWrite( g.template levelGridView< VTK_Partition >( 0 ), Dune::VTK::conforming );
-  doWrite( g.template levelGridView< VTK_Partition >( 0 ), Dune::VTK::nonconforming );
-  doWrite( g.template levelGridView< VTK_Partition >( g.maxLevel() ), Dune::VTK::conforming );
-  doWrite( g.template levelGridView< VTK_Partition >( g.maxLevel() ), Dune::VTK::nonconforming );
+  doWrite( g.template leafGridView(), Dune::VTK::conforming );
+  doWrite( g.template leafGridView(), Dune::VTK::nonconforming );
+  doWrite( g.template levelGridView( 0 ), Dune::VTK::conforming );
+  doWrite( g.template levelGridView( 0 ), Dune::VTK::nonconforming );
+  doWrite( g.template levelGridView( g.maxLevel() ), Dune::VTK::conforming );
+  doWrite( g.template levelGridView( g.maxLevel() ), Dune::VTK::nonconforming );
 }
 
 int main(int argc, char **argv)
 {
   try {
 
-    int n[] = { 5, 5, 5, 5 };
-    double h[] = { 1.0, 2.0, 3.0, 4.0 };
+    const Dune::MPIHelper &mpiHelper = Dune::MPIHelper::instance(argc, argv);
 
-    vtkCheck<1>(n,h);
-    vtkCheck<2>(n,h);
-    vtkCheck<3>(n,h);
+    if(mpiHelper.rank() == 0)
+      std::cout << "subsamplingvtktest: MPI_Comm_size == " << mpiHelper.size()
+                << std::endl;
+
+    {
+      Dune::array<int,1> n = { { 5 } };
+      Dune::FieldVector<double,1> h = { 1.0 };
+      vtkCheck<1>(n,h);
+    }
+    {
+      Dune::array<int,2> n = { { 5, 5 } };
+      Dune::FieldVector<double,2> h = { 1.0, 2.0 };
+      vtkCheck<2>(n,h);
+    }
+    {
+      Dune::array<int,3> n = { { 5, 5, 5 } };
+      Dune::FieldVector<double,3> h = { 1.0, 2.0, 3.0 };
+      vtkCheck<3>(n,h);
+    }
 
   } catch (Dune::Exception &e) {
     std::cerr << e << std::endl;
